@@ -5,6 +5,7 @@ import pytest
 from compas.datastructures import Mesh
 from compas.geometry import Frame
 from compas.geometry import Scale
+from compas.geometry import Rotation
 
 import compas_fab
 from compas_fab.backends import RosClient
@@ -19,6 +20,7 @@ def add_imports(doctest_namespace):
     doctest_namespace["Frame"] = Frame
     doctest_namespace["Scale"] = Scale
     doctest_namespace["compas_fab"] = compas_fab
+    doctest_namespace["Rotation"] = Rotation
 
 
 @pytest.fixture(scope="session", autouse=True)
